[][src]Struct cantact::Channel

pub struct Channel {
    pub bitrate: u32,
    pub enabled: bool,
    pub loopback: bool,
    pub monitor: bool,
}

Configuration for a device's CAN channel.

Fields

bitrate: u32

Bitrate of the channel in bits/second

enabled: bool

When true, channel should be enabled when device starts

loopback: bool

When true, device is configured in hardware loopback mode

monitor: bool

When true, device will not transmit on the bus.