[−][src]Struct cantact::Channel
Configuration for a device's CAN channel.
Fields
bitrate: u32Bitrate of the channel in bits/second
enabled: boolWhen true, channel should be enabled when device starts
loopback: boolWhen true, device is configured in hardware loopback mode
monitor: boolWhen true, device will not transmit on the bus.